@@ -2,13 +2,17 @@
 """Provides programs to process and analyze EVE data."""
 from __future__ import absolute_import
 
-from sunpy.lightcurve import LightCurve
-
 import os
-from pandas.io.parsers import read_csv
+import numpy as np
 from datetime import datetime  
 
 import matplotlib.pyplot as plt
+from pandas.io.parsers import read_csv
+from os.path import basename
+
+from sunpy.lightcurve import LightCurve
+
+__all__ = ['EVELightCurve']
 
 class EVELightCurve(LightCurve):
     """SDO EVE light curve definition
@@ -17,22 +21,22 @@ class EVELightCurve(LightCurve):
     --------
     import sunpy
     eve = sunpy.lightcurve.EVELightCurve.create()
-    eve = sunpy.lightcurve.EVELightCurve.create('~/Downloads/EVE_Fe_IX_171_averages.csv')
     eve = sunpy.lightcurve.EVELightCurve.create('2012/06/20')
+    eve = sunpy.lightcurve.EVELightCurve.create(sunpy.data.test.EVE_AVERAGES_CSV)
     eve = sunpy.lightcurve.EVELightCurve.create("http://lasp.colorado.edu/eve/data_access/quicklook/quicklook_data/L0CS/LATEST_EVE_L0CS_DIODES_1m.txt")
-    eve.show()
+    eve.peek(subplots=True)
     
     References
     ----------
     | http://lasp.colorado.edu/home/eve/data/data-access/
     """
 
-    def peek(self, **kwargs):
+    def peek(self, column = None, **kwargs):
         figure = plt.figure()
         # Choose title if none was specified
-        if not kwargs.has_key("title"):
+        if not kwargs.has_key("title") and column is None:
             if len(self.data.columns) > 1:
-                kwargs['title'] = 'EVE GOES Proxy Xray Flux (1 minute data)'
+                kwargs['title'] = 'EVE (1 minute data)'
             else:
                 if self._filename is not None:
                     base = self._filename.replace('_', ' ')
@@ -40,10 +44,14 @@ class EVELightCurve(LightCurve):
                 else:
                     kwargs['title'] = 'EVE Averages'
 
-        self.plot(**kwargs)
-        
+        if column is None:
+            self.plot(**kwargs)
+        else:
+            data = self.data[column]
+            if not kwargs.has_key("title"):
+                kwargs['title'] = 'EVE ' + column.replace('_', ' ')
+            data.plot(**kwargs)
         figure.show()
-        
         return figure
         
     @staticmethod
@@ -56,6 +64,7 @@ class EVELightCurve(LightCurve):
         """Returns a URL to the EVE data for the specified date
         
             @NOTE: currently only supports downloading level 0 data
+            .TODO: No data available prior to 2010/03/01!
         """
         base_url = 'http://lasp.colorado.edu/eve/data/quicklook/L0CS/SpWx/'
         return base_url + date.strftime('%Y/%Y%m%d') + '_EVE_L0CS_DIODES_1m.txt'
@@ -63,6 +72,7 @@ class EVELightCurve(LightCurve):
     @classmethod
     def _parse_csv(cls, filepath):
         """Parses an EVE CSV file"""
+        cls._filename = basename(filepath)
         with open(filepath, 'rb') as fp:
             # Determine type of EVE CSV file and parse
             line1 = fp.readline()
@@ -81,29 +91,38 @@ class EVELightCurve(LightCurve):
     @staticmethod
     def _parse_level_0cs(fp):
         """Parses and EVE Level 0CS file"""
-        header = ""
-        
-        fields = ('xrs-b', 'xrs-a', 'sem', 'ESPquad', 'esp171', 
-                  'esp257', 'esp304', 'esp366', 'espdark', 'megsp', 'megsdark', 
-                  'q0esp', 'q1esp', 'q2esp', 'q3esp', 'cmlat', 'cmlon')
-        
+        header = []
+        fields = []
         line = fp.readline()
-        
-        # Read comment at top of file
+        header.append(line)
+        # Read header at top of file
         while line.startswith(";"):
-            header += line
+            header.append(line)
             line = fp.readline()
-            
-        # Next line is YYYY DOY MM DD
-        parts = line.split(" ")
+
+        fieldnames_start = False
+        for l in header:
+            if l.startswith("; Format:"):
+                fieldnames_start = False
+            if fieldnames_start:
+                fields.append(l.split(":")[0].replace(';', ' ').strip())        
+            if l.startswith("; Column descriptions:"):
+                fieldnames_start = True
+
+        # Next line is YYYY DOY MM DD        
+        date_parts = line.split(" ")
                 
-        year = int(parts[0])
-        month = int(parts[2])
-        day = int(parts[3])
+        year = int(date_parts[0])
+        month = int(date_parts[2])
+        day = int(date_parts[3])
+        #last_pos = fp.tell()
+        #line = fp.readline()
+        #el = line.split()
+        #len
         
         # function to parse date column (HHMM)
         parser = lambda x: datetime(year, month, day, int(x[0:2]), int(x[2:4]))
 
-        data = read_csv(fp, sep="\s*", names=fields, index_col=0, date_parser=parser)
-        
+        data = read_csv(fp, sep="\s*", names=fields, index_col=0, date_parser=parser, header = None)
+        #data.columns = fields
         return header, data
